==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/ro.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'ro', {
	button: {
		title: 'Proprietăţi buton',
		text: 'Text (Valoare)',
		type: 'Tip',
		typeBtn: 'Buton',
		typeSbm: 'Trimite',
		typeRst: 'Reset'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Proprietăţi bifă (Checkbox)',
		radioTitle: 'Proprietăţi buton radio (Radio Button)',
		value: 'Valoare',
		selected: 'Selectat',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Proprietăţi formular (Form)',
		menu: 'Proprietăţi formular (Form)',
		action: 'Acţiune',
		method: 'Metodă',
		encoding: 'Encodare'
	},
	hidden: {
		title: 'Proprietăţi câmp ascuns (Hidden Field)',
		name: 'Nume',
		value: 'Valoare'
	},
	select: {
		title: 'Proprietăţi câmp selecţie (Selection Field)',
		selectInfo: 'Informaţii',
		opAvail: 'Opţiuni disponibile',
		value: 'Valoare',
		size: 'Mărime',
		lines: 'linii',
		chkMulti: 'Permite selecţii multiple',
		required: 'Required', // MISSING
		opText: 'Text',
		opValue: 'Valoare',
		btnAdd: 'Adaugă',
		btnModify: 'Modifică',
		btnUp: 'Sus',
		btnDown: 'Jos',
		btnSetValue: 'Setează ca valoare selectată',
		btnDelete: 'Şterge'
	},
	textarea: {
		title: 'Proprietăţi suprafaţă text (Textarea)',
		cols: 'Coloane',
		rows: 'Linii'
	},
	textfield: {
		title: 'Proprietăţi câmp text (Text Field)',
		name: 'Nume',
		value: 'Valoare',
		charWidth: 'Lărgimea caracterului',
		maxChars: 'Caractere maxime',
		required: 'Required', // MISSING
		type: 'Tip',
		typeText: 'Text',
		typePass: 'Parolă',
		typeEmail: 'Email',
		typeSearch: 'Cauta',
		typeTel: 'Numar de telefon',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/forms/lang/ro.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'ro', {
	button: {
		title: 'Proprietăţi buton',
		text: 'Text (Valoare)',
		type: 'Tip',
		typeBtn: 'Buton',
		typeSbm: 'Trimite',
		typeRst: 'Reset'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Proprietăţi bifă (Checkbox)',
		radioTitle: 'Proprietăţi buton radio (Radio Button)',
		value: 'Valoare',
		selected: 'Selectat',
		required: 'Obligatoriu'
	},
	form: {
		title: 'Proprietăţi formular (Form)',
		menu: 'Proprietăţi formular (Form)',
		action: 'Acţiune',
		method: 'Metodă',
		encoding: 'Encodare'
	},
	hidden: {
		title: 'Proprietăţi câmp ascuns (Hidden Field)',
		name: 'Nume',
		value: 'Valoare'
	},
	select: {
		title: 'Proprietăţi câmp selecţie (Selection Field)',
		selectInfo: 'Informaţii',
		opAvail: 'Opţiuni disponibile',
		value: 'Valoare',
		size: 'Mărime',
		lines: 'linii',
		chkMulti: 'Permite selecţii multiple',
		required: 'Selecție necesară',
		opText: 'Text',
		opValue: 'Valoare',
		btnAdd: 'Adaugă',
		btnModify: 'Modifică',
		btnUp: 'Sus',
		btnDown: 'Jos',
		btnSetValue: 'Setează ca valoare selectată',
		btnDelete: 'Şterge'
	},
	textarea: {
		title: 'Proprietăţi suprafaţă text (Textarea)',
		cols: 'Coloane',
		rows: 'Linii'
	},
	textfield: {
		title: 'Proprietăţi câmp text (Text Field)',
		name: 'Nume',
		value: 'Valoare',
		charWidth: 'Lărgimea caracterului',
		maxChars: 'Număr maxim de caractere',
		required: 'Necesar',
		type: 'Tip',
		typeText: 'Text',
		typePass: 'Parolă',
		typeEmail: 'Email',
		typeSearch: 'Cauta',
		typeTel: 'Numar telefon',
		typeUrl: 'URL'
	}
} );
